SimplePackingStrategy

Enum SimplePackingStrategy 

#[non_exhaustive]
pub enum SimplePackingStrategy { Decimal(i16), }
Strategies applied when performing simple packing on numerical sequences. Simple packing is a method for discretizing continuous numerical values as integers, and various approaches can be taken during this process.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Decimal(i16)

A strategy specifying how many decimal places to consider valid for the numbers. This strategy is effective for various types of data, such as observation data obtained from specific observation instruments, where precision is clearly defined.